sievetools.BaseResidueClass
===========================

.. abjad-lineage:: abjad.tools.sievetools.BaseResidueClass.BaseResidueClass

.. autoclass:: abjad.tools.sievetools.BaseResidueClass.BaseResidueClass

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.sievetools.BaseResidueClass.BaseResidueClass.__and__
      ~abjad.tools.sievetools.BaseResidueClass.BaseResidueClass.__eq__
      ~abjad.tools.sievetools.BaseResidueClass.BaseResidueClass.__format__
      ~abjad.tools.sievetools.BaseResidueClass.BaseResidueClass.__ne__
      ~abjad.tools.sievetools.BaseResidueClass.BaseResidueClass.__or__
      ~abjad.tools.sievetools.BaseResidueClass.BaseResidueClass.__repr__
      ~abjad.tools.sievetools.BaseResidueClass.BaseResidueClass.__xor__

Bases
-----

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Special methods
---------------

.. automethod:: abjad.tools.sievetools.BaseResidueClass.BaseResidueClass.__and__
   :noindex:

.. automethod:: abjad.tools.sievetools.BaseResidueClass.BaseResidueClass.__eq__
   :noindex:

.. automethod:: abjad.tools.sievetools.BaseResidueClass.BaseResidueClass.__format__
   :noindex:

.. automethod:: abjad.tools.sievetools.BaseResidueClass.BaseResidueClass.__ne__
   :noindex:

.. automethod:: abjad.tools.sievetools.BaseResidueClass.BaseResidueClass.__or__
   :noindex:

.. automethod:: abjad.tools.sievetools.BaseResidueClass.BaseResidueClass.__repr__
   :noindex:

.. automethod:: abjad.tools.sievetools.BaseResidueClass.BaseResidueClass.__xor__
   :noindex:
